import { FlatList, View } from "react-native";
import { AccordionItem } from "../../../../Components/Accordion";
import {
  AppContext,
  AppStyles,
  Constants,
  ModalContainer,
} from "../../../../utils";
import { useContext } from "react";
import { useTranslation } from "react-i18next";
import { InfoHeader } from "../..";

const helpDataDe = [
  {
    topicText: "Allgemeine Fragen",
    question:
      "Was ist die grundlegende Funktionalität der Handy-App zur Gerätesteuerung?",
    answer:
      "Die Handy-App ermöglicht es Ihnen, kompatible Geräte über Ihr Smartphone oder Tablet zu steuern. Sie können verschiedene Funktionen aktivieren, Einstellungen ändern und Aktionen aus der Ferne ausführen.",
  },
  {
    question: "Welche Arten von Geräten können über die App gesteuert werden?",
    answer:
      "Unsere App unterstützt eine Vielzahl von Geräten, darunter Smart-Home-Geräte, Unterhaltungselektronik, Haushaltsgeräte und mehr.",
  },
  {
    question: "Ist die App für Android- und iOS-Geräte verfügbar?",
    answer:
      "Ja, die App ist sowohl für Android- als auch für iOS-Geräte verfügbar. Sie können sie im Google Play Store bzw. im Apple App Store herunterladen.",
  },
  {
    question: "Wo kann ich die App herunterladen?",
    answer:
      "Sie können die App direkt aus dem Google Play Store (für Android) oder dem Apple App Store (für iOS) herunterladen und installieren.",
  },
  {
    question:
      "Benötige ich eine Internetverbindung, um das Gerät über die App zu steuern?",
    answer:
      "Ja, eine aktive Internetverbindung (Wi-Fi oder mobile Daten) ist erforderlich, um die App mit dem Gerät zu verbinden und die Steuerungsfunktionen zu nutzen.",
  },
  {
    question: "Unterstützt die App mehrere Geräte gleichzeitig?",
    answer:
      "Ja, die App ermöglicht es Ihnen, mehrere kompatible Geräte gleichzeitig zu steuern und zwischen ihnen zu wechseln.",
  },
  {
    topicText: "Einrichtung und Verbindung",
    question:
      "Wie richte ich die Verbindung zwischen der App und meinem Gerät ein?",
    answer:
      "Die genaue Einrichtung kann je nach Gerät variieren, aber normalerweise müssen Sie die App öffnen, das Gerät auswählen und den Anweisungen auf dem Bildschirm folgen, um die Verbindung herzustellen.",
  },
  {
    question:
      "Welche Schritte sind erforderlich, um das Gerät zum ersten Mal mit der App zu verbinden?",
    answer:
      "Starten Sie die App, erstellen Sie ein Konto (falls erforderlich), fügen Sie das Gerät hinzu, indem Sie es aus der Liste der verfügbaren Geräte auswählen, und folgen Sie den Anweisungen zur Verbindungsherstellung.",
  },
  {
    question:
      "Benötige ich spezielle Einstellungen am Gerät, um die Verbindung herzustellen?",
    answer:
      "Ja, in den meisten Fällen müssen Sie sicherstellen, dass das Gerät eingeschaltet und im Verbindungsmodus ist, bevor Sie versuchen, es über die App zu verbinden.",
  },
  {
    question:
      "Welche Arten von Verbindungsmethoden werden von der App unterstützt (z. B. Bluetooth, WLAN, etc.)?",
    answer:
      "Unsere App unterstützt in der Regel WLAN-Verbindungen, um eine stabile und zuverlässige Steuerung über größere Entfernungen zu ermöglichen.",
  },
  {
    question:
      "Was sollte ich tun, wenn die Verbindung zwischen der App und dem Gerät verloren geht?",
    answer:
      "Überprüfen Sie zuerst Ihre Internetverbindung. Wenn das Problem weiterhin besteht, können Sie versuchen, das Gerät aus der App zu entfernen und erneut hinzuzufügen. Gegebenenfalls kann ein Neustart des Geräts helfen.",
  },
];

const helpDataEn = [
  {
    topicText: "General Questions",
    question:
      "What is the basic functionality of the mobile app for device control?",
    answer:
      "The mobile app allows you to control compatible devices using your smartphone or tablet. You can activate various functions, change settings, and perform actions remotely.",
  },
  {
    question: "What types of devices can be controlled through the app?",
    answer:
      "Our app supports a variety of devices, including smart home devices, entertainment electronics, household appliances, and more.",
  },
  {
    question: "Is the app available for both Android and iOS devices?",
    answer:
      "Yes, the app is available for both Android and iOS devices. You can download it from the Google Play Store or the Apple App Store.",
  },
  {
    question: "Where can I download the app?",
    answer:
      "You can download and install the app directly from the Google Play Store (for Android) or the Apple App Store (for iOS).",
  },
  {
    question:
      "Do I need an internet connection to control the device through the app?",
    answer:
      "Yes, an active internet connection (Wi-Fi or mobile data) is required to connect the app to the device and use the control functions.",
  },
  {
    question: "Does the app support multiple devices simultaneously?",
    answer:
      "Yes, the app allows you to control multiple compatible devices simultaneously and switch between them.",
  },
  {
    topicText: "Setup and Connection",
    question: "How do I set up the connection between the app and my device?",
    answer:
      "The exact setup process may vary depending on the device, but typically, you need to open the app, select the device, and follow the on-screen instructions to establish the connection.",
  },
  {
    question:
      "What steps are required to initially connect the device to the app?",
    answer:
      "Launch the app, create an account (if required), add the device by selecting it from the list of available devices, and follow the instructions for establishing the connection.",
  },
  {
    question:
      "Do I need specific settings on the device to establish the connection?",
    answer:
      "Yes, in most cases, you need to ensure that the device is powered on and in pairing mode before attempting to connect it through the app.",
  },
  {
    question:
      "What types of connection methods are supported by the app (e.g., Bluetooth, Wi-Fi, etc.)?",
    answer:
      "Our app typically supports Wi-Fi connections to enable stable and reliable control over longer distances.",
  },
  {
    question:
      "What should I do if the connection between the app and the device is lost?",
    answer:
      "First, check your internet connection. If the issue persists, you can try removing and re-adding the device from the app. If necessary, restarting the device might help.",
  },
];

export default function HelpCenterModalContent() {
  const appContext = useContext(AppContext);
  const { t } = useTranslation();

  const helpData =
    appContext.appLanguage === Constants.defaultLanguage
      ? helpDataDe
      : helpDataEn;

  return (
    <ModalContainer withoutPadding>
      <FlatList
        data={helpData}
        ListHeaderComponent={
          <InfoHeader
            appContext={appContext}
            iconName="help-circle"
            text={t("screens.help.modalHelpCenter.pageInfoText")}
          />
        }
        ListFooterComponent={<View style={AppStyles.appBottom} />}
        renderItem={({ item, index }) => (
          <AccordionItem
            key={index}
            disablePaddingBottom={helpData[index + 1]?.topicText === undefined}
            appContext={appContext}
            cardTopicText={item.topicText}
            title={item.question}
            description={item.answer}
          />
        )}
      />
    </ModalContainer>
  );
}
